.. BioMol documentation master file, created by
   sphinx-quickstart on Wed Sep 17 17:57:30 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

BioMol documentation
====================
   
`BioMol <https://github.com/CSSB-SNU/BioMol>`_ is a molecular data engine that provides PyMOL-like selections and NumPy-style operations, designed for machine learning and large-scale molecular analysis.

.. grid:: 1 2 2 2
   :gutter: 4
   :class-container: sd-text-center

   .. grid-item-card:: Getting Started
      :class-card: intro-card
      :shadow: md

      Explore the library overview, installation guide, and introductory tutorials.

      +++

      .. button-ref:: getting_started/index
         :ref-type: doc
         :click-parent:
         :color: secondary
         :expand:

         To the Getting Started Guide

   .. grid-item-card:: Concepts 
      :class-card: intro-card
      :shadow: md

      Understand the core concepts and data structures behind BioMol.

      +++

      .. button-ref:: concepts/index
         :ref-type: doc
         :click-parent:
         :color: secondary
         :expand:

         To the Concepts Guide

   .. grid-item-card:: Examples 
      :class-card: intro-card
      :shadow: md

      Explore focused examples demonstrating common workflows and analysis tasks.

      +++

      .. button-ref:: examples
         :ref-type: doc
         :click-parent:
         :color: secondary
         :expand:

         To the Examples Gallery

   .. grid-item-card:: API Reference
      :class-card: intro-card
      :shadow: md

      Browse detailed documentation of all public classes and functions.

      +++

      .. button-ref:: api/index
         :ref-type: doc
         :click-parent:
         :color: secondary
         :expand:

         To the API Reference


.. toctree::
   :maxdepth: 2
   :hidden:
   :titlesonly:

   getting_started/index
   concepts/index
   examples
   api/index
